==> huaweicloudsdkvpn-3.1.116-py2.py3-none-any.whl: huaweicloudsdkvpn/v5/model/remove_vpn_user_from_group_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RemoveVpnUserFromGroupRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'users': 'list[OpVpnUser]'
    }

    attribute_map = {
        'users': 'users'
    }

    def __init__(self, users=None):
        """RemoveVpnUserFromGroupRequestBody

        The model defined in huaweicloud sdk

        :param users: 用户列表信息
        :type users: list[:class:`huaweicloudsdkvpn.v5.OpVpnUser`]
        """
        
        

        self._users = None
        self.discriminator = None

        self.users = users

    @property
    def users(self):
        """Gets the users of this RemoveVpnUserFromGroupRequestBody.

        用户列表信息

        :return: The users of this RemoveVpnUserFromGroupRequestBody.
        :rtype: list[:class:`huaweicloudsdkvpn.v5.OpVpnUser`]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this RemoveVpnUserFromGroupRequestBody.

        用户列表信息

        :param users: The users of this RemoveVpnUserFromGroupRequestBody.
        :type users: list[:class:`huaweicloudsdkvpn.v5.OpVpnUser`]
        """
        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveVpnUserFromGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpn-3.1.154-py2.py3-none-any.whl: huaweicloudsdkvpn/v5/model/remove_vpn_user_from_group_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RemoveVpnUserFromGroupRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'users': 'list[OpVpnUser]'
    }

    attribute_map = {
        'users': 'users'
    }

    def __init__(self, users=None):
        r"""RemoveVpnUserFromGroupRequestBody

        The model defined in huaweicloud sdk

        :param users: 用户列表信息
        :type users: list[:class:`huaweicloudsdkvpn.v5.OpVpnUser`]
        """
        
        

        self._users = None
        self.discriminator = None

        self.users = users

    @property
    def users(self):
        r"""Gets the users of this RemoveVpnUserFromGroupRequestBody.

        用户列表信息

        :return: The users of this RemoveVpnUserFromGroupRequestBody.
        :rtype: list[:class:`huaweicloudsdkvpn.v5.OpVpnUser`]
        """
        return self._users

    @users.setter
    def users(self, users):
        r"""Sets the users of this RemoveVpnUserFromGroupRequestBody.

        用户列表信息

        :param users: The users of this RemoveVpnUserFromGroupRequestBody.
        :type users: list[:class:`huaweicloudsdkvpn.v5.OpVpnUser`]
        """
        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveVpnUserFromGroupRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
